#
# spec file for package skupper
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           skupper
Version:        2.1.0
Release:        1.1
Summary:        Virtual Application Network, enabling rich hybrid cloud communication
License:        Apache-2.0
URL:            https://github.com/skupperproject/skupper
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
Skupper enables cloud communication by enabling you to create a Virtual
Application Network.

This application layer network decouples addressing from the underlying network
infrastructure. This enables secure communication without a VPN.

You can use Skupper to create a network from namespaces in one or more
Kubernetes clusters as described in the Getting Started. This guide describes a
simple network, however there are no restrictions on the topology created which
can include redundant paths.

Connecting one Skupper site to another site enables communication both ways.
Communication can occur using any path available on the network, that is,
direct connections are not required to enable communication.

Skupper supports anycast and multicast communication using the application
layer network (VAN), allowing you to configure your topology to match business
requirements.

Skupper does not require any special privileges, that is, you do not require
the cluster-admin role to create networks.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/skupperproject/skupper/pkg/version.Version=%{version}" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version | grep 'cli.*%{version}'

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Thu Jul 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.1.0:
  https://github.com/skupperproject/skupper/milestone/4?closed=1
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.0.1:
  * Changelog
  - Updated to Golang 1.24
  - Updated artifact script generators
  - Added version command improvements
  - Avoided container name conflicts
  - Updated data when regenerating a secret
  - Customized CLI & router images in the bootstrap script
  - Fixed panic when trying to set annotations on router config
  - Added debug dump command for kube environments
  * Additional Fixes
  - https://github.com/skupperproject/skupper/issues/2009
  - https://github.com/skupperproject/skupper/issues/2029
  - https://github.com/skupperproject/skupper/issues/1994
  - https://github.com/skupperproject/skupper/issues/2054
  - https://github.com/skupperproject/skupper/issues/1957
  - https://github.com/skupperproject/skupper/issues/2023
* Fri Mar  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.0.0:
  * Changelog
  - Automate secret generation in network-observer chart
  - Relabeling podman containers to allow v1 and v2 to coexist
  - Add ensure-secret command to network observer
  - Added install/uninstall system commands
  - Site state serialized using flat structure (non-kube
    platforms)
  - Add ability to configure labels and annotations on created
    resources
  - Improved handing of conflict between multiple controllers
  - Add means of configuring site sizing
  - Cache the configured platform
  * Fixes
  - https://github.com/skupperproject/skupper/issues/1958
  - https://github.com/skupperproject/skupper/issues/1897
  - https://github.com/skupperproject/skupper/issues/1930
  - https://github.com/skupperproject/skupper/issues/1979
  - https://github.com/skupperproject/skupper/issues/1862
  - https://github.com/skupperproject/skupper/issues/1956
  - https://github.com/skupperproject/skupper/issues/1942
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.8.3:
  * update for 1.8.3
  * remove external process log (#1865)
  * Fixes internal console-auth implementation (#1833)
  * Ensure podman service containers bind correct hosts (#1799)
  * Update test images for ARM and OCP 3.11 (#1652)
  * Add stability to TestGateway and TestBasic tests (#1766)
* Mon Nov  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.2:
  * update for 1.8.2
  * refine peer link deletion (#1726)
  * Fixed version in update test (#1711)
  * Cleanup old link records.  When incoming link is deleted,
    remove corresponding outgoing link.   (#1699)
  * add v2 section (#1687)
  * Update link cost when receiving a flow record (#1695)
  * Podman sites update issue (#1675)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * update for 1.8.1
  * Mark the test as failed, if bad URL from token
  * Assorted fixes on -use-cluster tests (#1391)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  * update for 1.8.1
  * Avoid hiding the cursor when displaying a spinner (#1616)
  * Update the collector to stop errant DNS Lookups (#1606)
  * Sets site-server processes as bound/exposed. (#1578)
  * pin router version to 2.6.1 for V1 (#1602)
  * Fix image-pull test when not using :main tag (#1592)
  * Adding flag: drop tcp connections (#1564)
  * keep original port assignments within a service
  * Ensure original target ports annotation is not overwritten once
    set
  * Remove confusing error message from configSyc log
  * Added Skupper token status command
  * Include labels from site spec on new secret
  * Configure oauth-proxy with random cookie secret
  * Incorrect podman version recommendation (#1450)
  * do not overwrite unrecognised fields in router config entities
  * TestBasic: address flaky test, improves debuggability (#1467)
  * Display only locally exposed services in status and service
    status commands for k8s and podman platforms (#1478)
  * update packages (#1480)
  * Removed unused attribute to keep it compatible with podman v5
    (#1483)
  * skupper init fixes for rootful podman (#1469)
  * Add expiry time to token.  When token is being used to create
    link verify the token hasn't expired.  If it has log a warning,
    but continue trying to bring up link.
  * skupper init for rootful podman should try
    /run/podman/podman.sock (#1464)
  * Updated format transformation to schema 2 (#1461)
  * Proper handling of job removal on TestGateway subtests (#1462)
* Sun Aug 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.3:
  * update for 1.7.3
  * update for 1.7.2
  * Include labels from site spec on new secret
  * Configure oauth-proxy with random cookie secret
  * update for 1.7.1
  * update packages (#1480)
  * Update for 1.7.0
  * Fix the early parsing of platform flag in init() (#1451)
  * Default ingress to route on openshift
  * Sk1765 fix flow protocol race (#1460)
* Sun Aug 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package skupper: Virtual Application Network, enabling rich
  hybrid cloud communication
